
HIJACK_LOGIN_REDIRECT_URL = "/admin/"  # where you want to be redirected to, after hijacking the user.
HIJACK_LOGOUT_REDIRECT_URL = "/admin/"  # where you want to be redirected to, after releasing the user.



from django.apps import AppConfig


default_app_config = 'leonardo_hijack.Config'


LEONARDO_URLS_CONF = "hijack.urls"

LEONARDO_APPS = [
	'leonardo_hijack',
	"hijack",
	"compat"
]

LEONARDO_MIDDLEWARES = [
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'hijack.middleware.HijackRemoteUserMiddleware',
    'django.contrib.auth.middleware.RemoteUserMiddleware',
]


class Config(AppConfig):
    name = 'leonardo_hijack'
    verbose_name = "leonardo-hijack"
